pub struct AuthenticationOptions { /* private fields */ }Expand description
Options for initiating a WebAuthn authentication request.
This structure contains the parameters needed to create a credential request to authenticate a user with a previously registered passkey. It follows the WebAuthn specification format for navigator.credentials.get() options.
The browser uses these options to prompt the user for their passkey and generate a signed authentication assertion.