pub struct AuthenticationStatus(pub bool);Expand description
Indicates the overall authentication status of a session.
This is a simple boolean wrapper that indicates whether a user is authenticated. It’s used as a return type from authentication check functions to explicitly communicate the authentication state.
Contains a boolean where true means the user is authenticated.
Tuple Fields
0: boolTrait Implementations
Sourceimpl Clone for AuthenticationStatus
impl Clone for AuthenticationStatus
Sourcefn clone(&self) -> AuthenticationStatus
fn clone(&self) -> AuthenticationStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AuthenticationStatus
Sourceimpl Debug for AuthenticationStatus
impl Debug for AuthenticationStatus
Sourceimpl Display for AuthenticationStatus
impl Display for AuthenticationStatus
impl Eq for AuthenticationStatus
Sourceimpl PartialEq for AuthenticationStatus
impl PartialEq for AuthenticationStatus
impl StructuralPartialEq for AuthenticationStatus